Module uim.model.helpers.policy
===============================

Classes
-------

`HandleMissingDataPolicy(value, names=None, *, module=None, qualname=None, type=None, start=1)`
:   Policy to handle missing data.

    ### Ancestors (in MRO)

    * enum.Enum

    ### Class variables

    `FILL_WITH_ZEROS`
    :   Fill missing data with zeros

    `SKIP_STROKE`
    :   Skip the stroke

    `THROW_EXCEPTION`
    :   Raise an exception